﻿<?php
require_once '../db.inc';

function get_default_filename($jahr, $nr) {
	return sprintf('lp%04d%02d.pdf', $jahr, $nr);
}


function render_head() {
    ?>
    <style media="screen" type="text/css">
        label {
            min-width: 70px;
        }
    </style>
<?php
}


function render_content() {
$db_table = "lektorenplan";
$dok_path = "../dok/";


$dbc = db_connect();

$id = -1;
$nr = 0;
$jahr = 0;
$anmerkung = "";

$old_pfad = "";

if (isset($_POST['edit']) || isset($_POST['edit_save'])) {
	$id = intval($_POST['id']);
	$stmt = $dbc->prepare("select jahr, nr, pfad, anmerkung from $db_table where id=?;");
	$stmt->bind_param("i", $id);
	$stmt->execute();
	$stmt->bind_result($jahr, $nr, $old_pfad, $anmerkung);
	$stmt->fetch();
	$stmt->close();
}

if (isset($_POST['add']) || isset($_POST['edit_save'])) {
	$errors = array();

	if (empty($_POST['jahr_nr'])) {
		if ($id < 0) $errors[] = 'Bitte Jahr/Nr angeben!';
	} else {
		$tmp = explode("/", $_POST['jahr_nr']);
		$jahr = intval($tmp[0]);
		$nr = intval($tmp[1]);
	}
	if ($jahr < 1900 || $jahr > 2100 || $nr < 1 || $nr > 12)  $errors[] = 'Ungültige Jahr/Nr Angaben!';
	if (!empty($_POST['anmerkung'])) $anmerkung = $_POST['anmerkung'];
	if (empty($anmerkung)) $anmerkung = null;
	
	if (empty($errors)) {
		$stmt = $dbc->prepare("select id from $db_table where jahr=? and nr=? and id!=?;");
		$stmt->bind_param("iii", $jahr, $nr, $id);
		$stmt->execute();
		$stmt->store_result();
		if ($stmt->num_rows > 0) $errors[] = 'Eintrag mit ausgewählter Jahr/Nr existiert bereits!';
		$stmt->close();
	}
	
	if (empty($_FILES['datei']['name'])) {
		if ($id < 0) {
			$errors[] = 'Bitte Datei auswählen!';
		} else {
			if (empty($errors)) {
				if (!rename($dok_path.$old_pfad, $dok_path.get_default_filename($jahr, $nr))) $errors[] = 'Fehler beim Verschieben der Datei!';
			}
		}
	} else {
		$stepOK = false;
		if (empty($errors)) {
			if ($_FILES['datei']['error'] == UPLOAD_ERR_OK && is_uploaded_file($_FILES['datei']['tmp_name'])) {
				if (move_uploaded_file($_FILES['datei']['tmp_name'], $dok_path.get_default_filename($jahr, $nr))) $stepOK = true;
			}
			if (!$stepOK) $errors[] = "Fehler beim Dateiupload; Fehlercode ".$_FILES['datei']['error'];
		}
	}
	
	$stepOK = false;
	if (empty($errors)) {
		if ($id < 0) {
			$stmt = $dbc->prepare("INSERT INTO $db_table (jahr, nr, pfad, anmerkung) VALUES (?, ?, ?, ?);");
			$stmt->bind_param("iiss", $jahr, $nr, get_default_filename($jahr, $nr), $anmerkung);
		} else {
			$stmt = $dbc->prepare("UPDATE $db_table SET jahr=?, nr=?, pfad=?, anmerkung=? WHERE id=?;");
			$stmt->bind_param("iissi", $jahr, $nr, get_default_filename($jahr, $nr), $anmerkung, $id);
		}
		$stepOK = $stmt->execute();
		$stmt->close();
		if (!$stepOK) $errors[] = "Fehler beim Speichern in der Datenbank!";
	}
	
	if (empty($errors)) {
		msg_succ("Lektorenplan erfolgreich gespeichert!");
		$id = -1;
		$anmerkung = "";
	} else msg_err($errors);
	
} elseif (isset($_POST['delete'])) {
	$stmt = $dbc->prepare("DELETE FROM $db_table WHERE id=?;");
	$mid = intval($_POST['id']);
	$stmt->bind_param("i", $mid);
	if ($stmt->execute()) msg_succ("Erfolgreich gelöscht!");
	else msg_err("Fehler beim Löschen!");
	$stmt->close();

}

?>
<form action="<?php echo getURL(); ?>" method="post" enctype="multipart/form-data">

<fieldset>
<legend>Lektorenplan <?php echo ($id < 0?'hinzufügen':'ändern')?></legend>

<label for="m_jahr_nr">Jahr/Nr:</label>
<select id="m_jahr_nr" name="jahr_nr" size="1">
<?php
if ($id < 0) {
	$result = $dbc->query("select jahr, nr from $db_table order by jahr desc, nr desc LIMIT 1;");
	$row = $result->fetch_array(MYSQLI_ASSOC);
	$jahr = $row['jahr'];
	$nr = $row['nr'];
	$result->close();
	if ($nr >= 12) {
		$nr = 1;
		$jahr++;
	} else {
		$nr++;
	}
}
$curJahr = $jahr-1;
$curNr = $nr;
for ($q = 0; $q < 24; $q++) {
	if ($curNr >= 12) {
		$curNr = 1;
		$curJahr++;
	} else {
		$curNr++;
	}
	if ($curJahr == $jahr && $curNr == $nr) {
		echo '<option selected="selected">'.$curJahr.' / '.$curNr."</option>";
	} else {
		echo "<option>".$curJahr.' / '.$curNr."</option>";
	}
}
?>
</select><br />

<label for="m_file">Datei:</label>
<input type="file" id = "m_file" name="datei" /><br />

<label for="m_anmerkung">Anmerkung:</label><br />
<textarea id="m_anmerkung" name="anmerkung" cols="60" rows="3"><?php echo $anmerkung; ?></textarea>
<br/>

<br/>
<?php if ($id < 0) { ?>
<input type="submit" name="add" value="Hinzufügen" />
<?php } else { ?>
<input type="hidden" name="id" value="<?php echo $id; ?>" />
<input type="submit" name="edit_save" value="Speichern" />
<input type="submit" name="cancel" value="Abbrechen" />
<?php } ?>

<br/>


</fieldset>

</form>

<br/>


<table border="1">
<?php

$result = $dbc->query("select id, jahr, nr, pfad, anmerkung from $db_table order by jahr desc, nr desc;");
$firstrow = true;
while ($row = $result->fetch_array(MYSQLI_ASSOC)) {
	if ($firstrow) {
		$firstrow = false;
		echo "<tr>";
		foreach ($row as $n => $v) {
			echo "<th>".$n."</th>";
		}
		echo "<td></td>";
		echo "</tr>";
	}
	echo "<tr>";
	foreach ($row as $n => $v) {
		if ($n == 'pfad') $v = '<a href="'.$dok_path.$v.'" target="_blank">'.$v.'</a>';
		echo "<td>".$v."</td>";
	}?>
	<td>
		<form action="<?php echo getURL(); ?>" method="post">
			<input type="hidden" name="id" value="<?php echo $row['id'];?>" />
			<input type="submit" name="edit" value="Bearbeiten" />
			<input type="submit" name="delete" value="Löschen" style="color: red;"  onClick="return confirm('Das ausgewählte Element wird unwiderruflich gelöscht!\n\nBitte Bestätigen zum Fortfahren...')" />
		</form>
	</td>
	<?php
	echo "</tr>";
}
$result->free();

?>
</table>

<?php	
$dbc->close();

}
?>